pub fn replace_exec_event_sender(sender: impl Into<EventSender<ExecutionEvent>>)Expand description
Replaces the execution event sender for the current thread.
pub fn replace_exec_event_sender(sender: impl Into<EventSender<ExecutionEvent>>)Replaces the execution event sender for the current thread.