pub fn replace_system_command_sender(
sender: impl Into<DispatchSender<SystemCommand>>,
)Expand description
Replaces the system command sender for the current thread.
pub fn replace_system_command_sender(
sender: impl Into<DispatchSender<SystemCommand>>,
)Replaces the system command sender for the current thread.