pub fn replace_system_event_sender(sender: impl Into<EventSender<SystemEvent>>)Expand description
Replaces the system event sender for the current thread.
pub fn replace_system_event_sender(sender: impl Into<EventSender<SystemEvent>>)Replaces the system event sender for the current thread.