pub fn try_get_exec_event_sender() -> Option<EventSender<ExecutionEvent>>Expand description
Attempts to get the thread-local execution event sender without panicking.
Returns None if the sender is not initialized (e.g., in test environments).
pub fn try_get_exec_event_sender() -> Option<EventSender<ExecutionEvent>>Attempts to get the thread-local execution event sender without panicking.
Returns None if the sender is not initialized (e.g., in test environments).