pub fn try_get_system_event_sender() -> Option<EventSender<SystemEvent>>Expand description
Attempts to get the thread-local system event sender without panicking.
Returns None if the sender is not initialized (e.g., in test environments).
pub fn try_get_system_event_sender() -> Option<EventSender<SystemEvent>>Attempts to get the thread-local system event sender without panicking.
Returns None if the sender is not initialized (e.g., in test environments).